[otrs-cvs] otrs/Kernel/System LinkObject.pm,1.66,1.67

"CVS commits notifications of OTRS.org" <[email protected]>
Newsgroups gmane.comp.otrs.cvs
Message-ID <[email protected]>
Comments:
Update of /home/cvs/otrs/Kernel/System
In directory lancelot:/tmp/cvs-serv5302/Kernel/System

Modified Files:
	LinkObject.pm 
Log Message:
Improved error message.

Author: mb

Index: LinkObject.pm
===================================================================
RCS file: /home/cvs/otrs/Kernel/System/LinkObject.pm,v
retrieving revision 1.66
retrieving revision 1.67
diff -2 -u -d -r1.66 -r1.67
--- LinkObject.pm	20 Nov 2012 15:35:39 -0000	1.66
+++ LinkObject.pm	20 Dec 2012 12:24:53 -0000	1.67
@@ -435,9 +435,10 @@
     );
 
     # check if wanted link type is allowed
     if ( !$PossibleTypesList{ $Param{Type} } ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "Not allowed to link $Param{SourceObject} with $Param{TargetObject}!",
+            Message =>
+                "Not possible to create a '$Param{Type}' link between $Param{SourceObject} and $Param{TargetObject}!",
         );
         return;
---------------------------------------------------------------------
@@ -435,9 +435,10 @@
     );
 
-    # check if wanted link type is allowed
+    # check if wanted link type is possible
     if ( !$PossibleTypesList{ $Param{Type} } ) {
         $Self->{LogObject}->Log(
OTRS mailing list: cvs-log - Webpage: http://otrs.org/
Archive: http://lists.otrs.org/pipermail/cvs-log
To unsubscribe: http://lists.otrs.org/cgi-bin/listinfo/cvs-log
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.